@@ -4,15 +4,14 @@
  * Released under GNU GPL v2. (See 'COPYING' for details.)
  *
  * Much of this code was shamelessly stolen from a sockets example
- * cooked up by LordVader@DALnet. His code worked; if mine doesn't, it's MY
- * fault, not his. :-) Per his request, here's some more headers...
+ * cooked up by LordVader@DALnet. His code worked; if this doesn't, it's 
+ * MY fault, not his. :-) Per his request, here's some more headers...
  */ 
 
 /*
  * Webdump program by Jesse Estum, a.k.a LordVader on DALnet.  darkdarth@yahoo.com
  * Re-distributable under the terms of the GNU General Public Licence version of your choice.
  * This header MUST remain in re-distributed versions.
- *
  */
 
 
@@ -42,6 +41,7 @@ static char trackname[100][NAMESIZE];
 static int cdi_flag;
 static int net_flag;
 static int cdi_check_matches (FILE *fd);
+static int noinfo_disp = 0;
 
 int cdi_status (void) {
   return cdi_flag;
@@ -219,6 +219,7 @@ int cdi_get_info_net (void) {
   struct sockaddr_in server_addr;
   struct hostent *h;
   char *l_msg, *l_buffer;
+  extern int h_errno;
   FILE *outfile;
 
   #ifdef DEBUG
@@ -227,7 +228,7 @@ int cdi_get_info_net (void) {
 
   if (net_flag == FALSE) return FALSE;
 
-  l_msg = (char *)malloc (128);
+  l_msg = (char *)malloc (NET_BUF_SZ);
   l_buffer = (char *)malloc (NET_BUF_SZ);
 
   if ((l_msg == NULL) || (l_buffer == NULL)) {
@@ -246,6 +247,13 @@ int cdi_get_info_net (void) {
 
   h = gethostbyname (REMOTE_SITE);
 
+  if (h == NULL) {
+    #ifdef DEBUG
+      fprintf (stderr, "\nh is null, probably a DNS error\n");
+    #endif
+    return FALSE;
+  }
+
   #ifdef DEBUG
     fprintf (stderr, ".");
   #endif
@@ -253,8 +261,11 @@ int cdi_get_info_net (void) {
   sockfd = socket(AF_INET, SOCK_STREAM, 0);
   server_addr.sin_family = AF_INET;
   server_addr.sin_port = htons(REMOTE_PORT);
-  server_addr.sin_addr = *((struct in_addr *)h->h_addr);
-  memset(server_addr.sin_zero, '\0', 8);
+  #ifdef DEBUG
+    fprintf (stderr, ".");
+  #endif
+  server_addr.sin_addr = *((struct in_addr *)h->h_addr_list[0]);
+  memset(server_addr.sin_zero, '\0', sizeof(server_addr.sin_zero));
 
   #ifdef DEBUG
     fprintf (stderr, ". done.\n");
@@ -291,7 +302,7 @@ int cdi_get_info_net (void) {
     fprintf (stderr, "Cleaning up...\n");
   #endif
   fclose(outfile);
-  close (sockfd);
+  close(sockfd);
   #if 0
     free (l_buffer);
     free (l_msg);
@@ -314,18 +325,25 @@ static int cdi_check_matches (FILE *fd) {
     if (s > 0) switch (i) { /* the latter is a sanity check */
       case 0:
               #ifdef UNKNOWN_CD_WARN
-                printf ("CD Index doesn't know about this CD. Track names unavailable.\n");
-                printf ("If you want to avoid this error in the future, consider submitting\n");
-                printf ("information about this CD to the CD Index by using this URL:\n");
-                printf ("%s\n", cd_subid());
+                #if DEBUG > 1
+                  fprintf (stderr, "About to print no-info message (%i)\n", noinfo_disp);
+                #endif
+                if (noinfo_disp == 0) {
+                  printf ("CD Index doesn't know about this CD. Track names unavailable.\n");
+                  printf ("If you want to avoid this error in the future, consider submitting\n");
+                  printf ("information about this CD to the CD Index by using this URL:\n");
+                  printf ("%s\n", cd_subid());
+                }
+                noinfo_disp++;
+                /* end blatant bug-concealing measures */
               #endif
               unlink(fname()); /* don't care about errors */
               break;
       case 1: break; /* this is the "good" case */
       default: printf ("CD Index claims multiple matches for this CD.\n");
                printf ("This is, of course, impossible.\n");
-               printf ("Please send email to dave@technopagan.org about this. In the meantime,\n");
-               printf ("track names will be unavailable.\n");
+               printf ("Please send email to dave@technopagan.org about this.\n");
+               printf ("In the meantime, track names are unavailable. Sorry.\n");
                break;
     } /* switch */
     else fgets(trknm, NAMESIZE, fd); /* clear to newline */
