@@ -21,7 +21,7 @@ void disk_directory(void) {
 
   printf ("Track  Time  (%i tracks / %2i:%02i)",
           trackz, disc_length/60, disc_length%60);
-  if (cdi_stat == CDI_OK) printf (" (ID %s)", cd_discid());
+  /* if (cdi_stat == CDI_OK) printf (" (ID %s)", cd_discid()); */
   printf ("\n");
   for (i=1; i<=trackz; i++) {
     int track_length = cd_track_length(i);
